<?php

return [

    'description',
    'answer',
    'summery',
    'note',
    'notes',
    'project_summary',
    'reply_heading',
    'comment',
    'message',
    'details',
    // Modules
    'job_description',
    'meta_description',
    'cover_letter',
    'candidate_comment',
    'remark',
    'reason',
    'about',
    'internal_note',
    'billing_address',
    'shipping_address',
    'item_summary',
    'note_details',
    'footer_script',
    'header_script',
    'header_description',
    'message2',
    'editedMessage',
];
